Anomaly
-------

The anomaly view into the model. Expects that the model being served
when accessing this route implements the ``anomaly()`` method
in order to calculate the anomaly key(s) for the response.

.. automodule:: gordo.server.views.anomaly
    :members:
    :undoc-members:
    :show-inheritance:
